//
use crate::prelude::*;
use kxio::fs::FileSystem;

pub fn run(fs: &FileSystem) -> Result<()> {
    let pathbuf = fs.base().join(".git-next.toml");
    if fs
        .path(&pathbuf)
        .exists()
        .with_context(|| format!("Checking for existing file: {}", pathbuf.display()))?
    {
        eprintln!(
            "The configuration file already exists at {} - not overwritting it.",
            pathbuf.display()
        );
    } else {
        fs.file(&pathbuf)
            .write(include_str!("../default.toml"))
            .with_context(|| format!("Writing file: {}", pathbuf.display()))?;
        println!(
            "Created a default configuration file at {}",
            pathbuf.display()
        );
    }
    Ok(())
}
